@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 12087 2020-04-17 08:10:05Z Becca $
+# $Id: __init__.py 12129 2020-04-29 00:01:19Z Trista $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Becca $ (last)
-# $Date: 2020-04-17 16:10:05 +0800 (週五, 17 四月 2020) $
-# $Revision: 12087 $
+# $Author: Trista $ (last)
+# $Date: 2020-04-29 08:01:19 +0800 (週三, 29 四月 2020) $
+# $Revision: 12129 $
 
 from __future__ import print_function
 
@@ -420,6 +420,9 @@ def attachSettings(settingsDict, warns=True, printDetail=True):
                     if 'SERVICE_DB_NAME' in os.environ 
                     else 'localhost'),
                 'DATABASE_PORT': '',
+                'OPTIONS':{
+                    'charset':'utf8mb4',
+                },
             }
 
         _get = lambda k: settingsDict.get(k, dd[k])
@@ -433,6 +436,7 @@ def attachSettings(settingsDict, warns=True, printDetail=True):
                     'PASSWORD': _get('DATABASE_PASSWORD'),
                     'HOST': _get('DATABASE_HOST'),
                     'PORT': _get('DATABASE_PORT'),
+                    'OPTIONS': _get('OPTIONS') if 'OPTIONS' in _get,
                 },
             },
         }
